@@ -4,17 +4,15 @@ import (
 	"crypto/rand"
 	"fmt"
 
-	"github.com/golang/glog"
-
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/klog"
 
 	operatorapi "github.com/openshift/api/operator/v1"
 
 	imageregistryv1 "github.com/openshift/cluster-image-registry-operator/pkg/apis/imageregistry/v1"
 	regopset "github.com/openshift/cluster-image-registry-operator/pkg/generated/clientset/versioned/typed/imageregistry/v1"
 	"github.com/openshift/cluster-image-registry-operator/pkg/parameters"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
 )
 
 // randomSecretSize is the number of random bytes to generate
@@ -35,7 +33,7 @@ func (c *Controller) Bootstrap() error {
 
 	// If no registry resource exists,
 	// let's create one with sane defaults
-	glog.Infof("generating registry custom resource")
+	klog.Infof("generating registry custom resource")
 
 	var secretBytes [randomSecretSize]byte
 	if _, err := rand.Read(secretBytes[:]); err != nil {
@@ -58,18 +56,8 @@ func (c *Controller) Bootstrap() error {
 		Status: imageregistryv1.ImageRegistryStatus{},
 	}
 
-	driver, err := storage.NewDriver(&cr.Spec.Storage, c.listers)
-	if err != nil && err != storage.ErrStorageNotConfigured {
-		return err
-	}
-
-	err = nil
-	if driver != nil {
-		err = driver.CompleteConfiguration(cr)
-	}
-
 	if genErr := c.generator.ApplyClusterOperator(cr); genErr != nil {
-		glog.Errorf("unable to apply cluster operator (bootstrap): %s", genErr)
+		klog.Errorf("unable to apply cluster operator (bootstrap): %s", genErr)
 	}
 
 	client, err := regopset.NewForConfig(c.kubeconfig)
@@ -77,10 +65,7 @@ func (c *Controller) Bootstrap() error {
 		return err
 	}
 
-	_, cerr := client.Configs().Create(cr)
-	if cerr != nil {
-		return cerr
-	}
+	_, err = client.Configs().Create(cr)
 	if err != nil {
 		return err
 	}
